==> kmyfirewall_1.0.orig.tar.gz: kmyfirewall-1.0/kmyfirewall/ruleoptionplugins/interface_option/kmfruleoptioneditinterface.h <==
//
// C++ Interface: kmfruleoptioneditiip
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@gmail.com>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KMFRULEOPTIONEDITINTERFACE_H
#define KMFRULEOPTIONEDITINTERFACE_H

#include "../../interfaces/kmfruleoptioneditinterface.h"

// KDE includes
#include <kparts/part.h>
#include <kparts/plugin.h>
#include <kparts/factory.h>
#include <kxmlgui.h>


class IPTRule;
class KMFRuleEditorInterface;
/**
@author Christian Hubinger
*/
class KMFRuleOptionEditorInterface : public KMFRuleOptionEditInterface {
	Q_OBJECT
public:
	KMFRuleOptionEditorInterface(QObject *parent = 0, const char *name = 0);

	~KMFRuleOptionEditorInterface();
	void loadRule( IPTRule* rule );	
	QWidget* editWidget();
	const QString& optionEditName() const;
	const QString& description() const;

private slots:
	void slotAddRuleOption(QString*, QPtrList< QString >* );
	void slotAddTargetOption(QString*, QPtrList< QString >* );
	void slotShowOverview();

private:
	KMFRuleEditorInterface *m_edit;
	IPTRule *m_rule;
	
};

class KInstance;

class KMFRuleOptionEditorInterfaceFactory : public KLibFactory {
	Q_OBJECT
public:
	KMFRuleOptionEditorInterfaceFactory( QObject *parent = 0, const char *name = 0 );
	virtual ~KMFRuleOptionEditorInterfaceFactory() {
/* 		delete s_instance; */
	};
	virtual QObject* createObject( QObject* parent = 0, const char* pname = 0,
	                               const char* name = "QObject",
	                               const QStringList &args = QStringList() );
	/*     static KInstance* instance(); */

/*private:
	static KInstance* s_instance;*/
};









#endif

==> kmyfirewall_1.1.1.orig.tar.gz: kmyfirewall-1.1.1/kmyfirewall/ruleoptionplugins/interface_option/kmfruleoptioneditinterface.h <==
//
// C++ Interface: kmfruleoptioneditiip
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KMFRULEOPTIONEDITINTERFACE_H
#define KMFRULEOPTIONEDITINTERFACE_H

#include "../../core/kmfruleoptioneditinterface.h"

// KDE includes
#include <kparts/part.h>
#include <kparts/plugin.h>
#include <kparts/factory.h>
#include <kxmlgui.h>

class KInstance;

namespace KMF {
class IPTRule;
class KMFRuleEditorInterface;
/**
@author Christian Hubinger
*/
class KMFRuleOptionEditorInterface : public KMFRuleOptionEditInterface {
	Q_OBJECT
public:
	KMFRuleOptionEditorInterface(QObject *parent = 0, const char *name = 0);

	~KMFRuleOptionEditorInterface();
	void loadRule( IPTRule* rule );	
	QWidget* editWidget();
	const QString& optionEditName() const;
	const QString& description() const;

private slots:
	void slotShowOverview();

private:
	KMFRuleEditorInterface *m_edit;
	IPTRule *m_rule;
	
};



class KMFRuleOptionEditorInterfaceFactory : public KLibFactory {
	Q_OBJECT
public:
	KMFRuleOptionEditorInterfaceFactory( QObject *parent = 0, const char *name = 0 );
	virtual ~KMFRuleOptionEditorInterfaceFactory() {
/* 		delete s_instance; */
	};
	virtual QObject* createObject( QObject* parent = 0, const char* pname = 0,
	                               const char* name = "QObject",
	                               const QStringList &args = QStringList() );
	/*     static KInstance* instance(); */

/*private:
	static KInstance* s_instance;*/
};
}








#endif
